@@ -12,7 +12,7 @@ use Test::BDD::Cucumber::Definitions::Validator qw(:all);
 use Test::More;
 use Try::Tiny;
 
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 
 our @EXPORT_OK = qw(
     http_response_content_read_zip
@@ -34,7 +34,7 @@ sub http_response_content_read_zip {
 
     my $error;
 
-    my $decoded_content = S->{http}->{response_object}->decoded_content();
+    my $decoded_content = S->{HTTP}->content();
 
     S->{zip}->{archive} = try {
         my $fh = IO::String->new( \$decoded_content );
